%BuildOptions = (%BuildOptions,
    NAME                => 'Postfix::ContentFilter',
    AUTHOR              => 'David Zurborg <zurborg@cpan.org>',
    VERSION_FROM        => 'lib/Postfix/ContentFilter.pm',
    ABSTRACT_FROM       => 'lib/Postfix/ContentFilter.pm',
    LICENSE             => 'open-source',
    PL_FILES            => {},
    PMLIBDIRS           => [qw[ lib ]],
    PREREQ_PM => {
		'Test::Most'        => 0,
		'Modern::Perl'      => 0,
		'Try::Tiny'         => 0.11,
		'IPC::Open3'        => 1.12,
    },
    dist => {
        COMPRESS            => 'gzip -9f',
        SUFFIX              => 'gz',
        CI                  => 'git add',
        RCS_LABEL           => 'true',
    },
    clean               => { FILES => 'Postfix-ContentFilter-* *~' },
    depend => {
	'$(FIRST_MAKEFILE)' => 'config/BuildOptions.pm',
    },
);
